﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Advantage.Data.Provider;

namespace WindowsFormsApplication1
{
    public partial class Form1 : Form
    {
        private AdsConnection cn;
        private AdsExtendedReader rdr;
        private Boolean IsDirty;


        public Form1()
        {
            InitializeComponent();
            cn = new AdsConnection("Data Source = C:\\ADSDB; TableType = ADT; ServerType = REMOTE; TrimTrailingSpaces = TRUE");
            cn.Open();
            AdsCommand cmd = cn.CreateCommand();
            cmd.CommandText = "biolife";
            cmd.CommandType = CommandType.TableDirect;
            rdr = cmd.ExecuteExtendedReader();
            rdr.RecordCache = 0;
            rdr.ActiveIndex = "Primary";
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            ReadRecord(1);
        }

        private void ReadRecord(Int32 mode)
        {
            IsDirty = true;
            switch (mode)
            {
                case 0: //read again
                    rdr.Read();
                    rdr.ReadPrevious();
                    break;
                case 1: //next in resultset
                    if (!rdr.Read()) rdr.ReadPrevious();
                    break;
                case -1: //prev in resultset
                    if (!rdr.ReadPrevious()) rdr.Read();
                    break;
                case -10: //first record
                    rdr.GotoTop();
                    break;
                case 10: //last record
                    rdr.GotoBottom();
                    break;
            }
            try
            {
                species_NoTextBox.Text = rdr["Species No"].ToString();
                categoryTextBox.Text = rdr["Category"].ToString();
                common_NameTextBox.Text = rdr["Common_Name"].ToString();
                species_NameTextBox.Text = rdr["Species Name"].ToString();
                length__cm_TextBox.Text = rdr["length (cm)"].ToString();
                length_InTextBox.Text = rdr["length_in"].ToString();
                notesTextBox.Text = rdr["notes"].ToString();
            }
            catch
            {
                species_NoTextBox.Text = "0";
                categoryTextBox.Text = "<NULL>";
                common_NameTextBox.Text = "<NULL>";
                species_NameTextBox.Text = "<NULL>";
                length__cm_TextBox.Text = "0";
                length_InTextBox.Text = "0";
                notesTextBox.Text = "<NULL>";
            }
            IsDirty = false;
        }

        private void SaveRecord()
        {
			try
			{
                rdr["Species No"] = System.Convert.ToInt32(species_NoTextBox.Text);
                rdr["Category"]=categoryTextBox.Text;
                rdr["Common_Name"] = common_NameTextBox.Text;
                rdr["Species Name"] = species_NameTextBox.Text;
                rdr["length (cm)"] = System.Convert.ToDouble(length__cm_TextBox.Text);
                rdr["length_in"] = System.Convert.ToDouble(length_InTextBox.Text);
                rdr["notes"] = notesTextBox.Text;
			}
			catch (Exception ex)
			{
                MessageBox.Show(ex.Message);
			}
			finally
			{
                try
                {
                    rdr.UnlockRecord();
                    ReadRecord(0);
                }
                catch
                {
                }
            }
        }

        private void button6_Click(object sender, EventArgs e)
        {
            SaveRecord();
        }

        private void TextBox_TextChanged(object sender, EventArgs e)
        {
            if (!IsDirty)
            {
                try
                {
                    rdr.LockRecord();
                    IsDirty = true;
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message);
                    ReadRecord(0);
                }
            }
        }

        private void button2_Click(object sender, EventArgs e)
        {
            if (IsDirty)
                SaveRecord();
            ReadRecord(-1);
        }

        private void button1_Click(object sender, EventArgs e)
        {
            if (IsDirty)
                SaveRecord();
            ReadRecord(-10);
        }

        private void button3_Click(object sender, EventArgs e)
        {
            if (IsDirty)
                SaveRecord();
            ReadRecord(1);
        }

        private void button4_Click(object sender, EventArgs e)
        {
            if (IsDirty)
                SaveRecord();
            ReadRecord(10);
        }

        private void button8_Click(object sender, EventArgs e)
        {
            if (IsDirty)
                rdr.UnlockRecord(); 
            ReadRecord(0);
        }

        private void button7_Click(object sender, EventArgs e)
        {
            if (IsDirty)
                SaveRecord();
            ReadRecord(0);
        }

        private void button5_Click(object sender, EventArgs e)
        {
            if (IsDirty)
                SaveRecord();
            IsDirty=true;
            rdr.AppendRecord();
            species_NoTextBox.Text = "0";
            categoryTextBox.Text = "";
            common_NameTextBox.Text = "";
            species_NameTextBox.Text = "";
            length__cm_TextBox.Text = "0";
            length_InTextBox.Text = "0";
            notesTextBox.Text = "";
        }

        private void button9_Click(object sender, EventArgs e)
        {
            rdr.DeleteRecord();
            ReadRecord(1);
        }

        private void checkFilter_CheckStateChanged(object sender, EventArgs e)
        {
            if (checkFilter.Checked && textFilter.Text.Length > 0)
            {
                try
                {
                    rdr.Filter = textFilter.Text;
                    ReadRecord(-10);
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message);
                    checkFilter.Checked = false;
                }
            }
            else
            {
                try
                {
                    checkFilter.Checked = false;
                    rdr.Filter = "";
                }
                catch
                {
                }
                ReadRecord(-10);
            }
        }

        private void textFilter_TextChanged(object sender, EventArgs e)
        {
            checkFilter.Checked = false;
        }

        private void textSeek_TextChanged(object sender, EventArgs e)
        {
            rdr.ActiveIndex = "common_name";
            rdr.Seek(new object[] {textSeek.Text}, AdsExtendedReader.SeekType.SoftSeek);
            ReadRecord(0);
        }

    }
}
